Security Advisories (9)
CVE-2020-11022 (2020-04-29)

In jQuery versions greater than or equal to 1.2 and before 3.5.0, passing HTML from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2020-11023 (2020-04-29)

In jQuery versions greater than or equal to 1.0.3 and before 3.5.0, passing HTML containing <option> elements from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2019-11358 (2019-04-20)

jQuery before 3.4.0, as used in Drupal, Backdrop CMS, and other products, mishandles jQuery.extend(true, {}, ...) because of Object.prototype pollution. If an unsanitized source object contained an enumerable __proto__ property, it could extend the native Object.prototype.

CVE-2015-9251 (2018-01-18)

jQuery before 3.0.0 is vulnerable to Cross-site Scripting (XSS) attacks when a cross-domain Ajax request is performed without the dataType option, causing text/javascript responses to be executed.

CVE-2011-4969 (2013-03-08)

Cross-site scripting (XSS) vulnerability in jQuery before 1.6.3, when using location.hash to select elements, allows remote attackers to inject arbitrary web script or HTML via a crafted tag.

CVE-2012-6708 (2018-01-18)

jQuery before 1.9.0 is vulnerable to Cross-site Scripting (XSS) attacks. The jQuery(strInput) function does not differentiate selectors from HTML in a reliable fashion. In vulnerable versions, jQuery determined whether the input was HTML by looking for the '<' character anywhere in the string, giving attackers more flexibility when attempting to construct a malicious payload. In fixed versions, jQuery only deems the input to be HTML if it explicitly starts with the '<' character, limiting exploitability only to attackers who can control the beginning of a string, which is far less common.

CVE-2020-7656 (2020-05-19)

jquery prior to 1.9.0 allows Cross-site Scripting attacks via the load method. The load method fails to recognize and remove "<script>" HTML tags that contain a whitespace character, i.e: "</script >", which results in the enclosed script logic to be executed.

CVE-2019-5428

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

CVE-2014-6071 (2018-01-16)

jQuery 1.4.2 allows remote attackers to conduct cross-site scripting (XSS) attacks via vectors related to use of the text method inside after.

NAME

Yancy::Guides::Tutorial - Yancy's First Steps

VERSION

version 1.080

DESCRIPTION

Yancy is a content management system (CMS) for Mojolicious. It includes an admin application to edit content and tools to quickly build an application.

Admin App

Yancy provides an application to edit content at the path /yancy on your website. Yancy can manage data in multiple databases using different backend modules. You can provide a URL string to tell Yancy how to connect to your database, or you can provide your database object. Yancy supports the following databases:

Postgres

PostgreSQL is supported through the Mojo::Pg module.

# PostgreSQL: A Mojo::Pg connection string
plugin Yancy => backend => 'postgresql://postgres@/test';

# PostgreSQL: A Mojo::Pg object
plugin Yancy => backend => Mojo::Pg->new( 'postgresql://postgres@/test' );

MySQL

MySQL is supported through the Mojo::mysql module.

# MySQL: A Mojo::mysql connection string
plugin Yancy => backend => 'mysql://user@/test';

# MySQL: A Mojo::mysql object
plugin Yancy => backend => Mojo::mysql->strict_mode( 'mysql://user@/test' );

SQLite

SQLite is supported through the Mojo::SQLite module. This is a good option if you want to try Yancy out.

# SQLite: A Mojo::SQLite connection string
plugin Yancy => backend => 'sqlite:test.db';

# SQLite: A Mojo::SQLite object
plugin Yancy => backend => Mojo::SQLite->new( 'sqlite::temp:' );

DBIx::Class

If you have a DBIx::Class schema, Yancy can use it to edit the content.

# DBIx::Class: A connection string
plugin Yancy => backend => 'dbic://My::Schema/dbi:SQLite:test.db';

# DBIx::Class: A DBIx::Class::Schema object
plugin Yancy => backend => My::Schema->connect( 'dbi:SQLite:test.db' );

Content Tools

Schema Information and Validation

Yancy scans your database to determine what kind of data is inside, but Yancy also accepts a JSON Schema to add more information about your data. You can add descriptions, examples, and other documentation that will appear in the admin application. You can also add type, format, and other validation information, which Yancy will use to validate input from users. See Yancy::Guides::Schema for how to define your schema.

plugin Yancy => backend => 'postgres://postgres@/test',
    schema => {
        employees => {
            title => 'Employees',
            description => 'Our crack team of loyal dregs.',
            properties => {
                address => {
                    description => 'Where to notify next-of-kin.',
                    # Regexp to validate this field
                    pattern => '^\d+ \S+',
                },
                email => {
                    # Use the browser's native e-mail input
                    format => 'email',
                },
            },
        },
    };

Data Helpers

Mojolicious::Plugin::Yancy provides helpers to work with your database content. These use the validations provided in the schema to validate user input. These helpers can be used in your route handlers to quickly add basic Create, Read, Update, and Delete (CRUD) functionality. See "HELPERS" in Mojolicious::Plugin::Yancy for a list of provided helpers.

# View a list of blog entries
get '/' => sub( $c ) {
    my @blog_entries = $c->yancy->list(
        blog_entries =>
        { published => 1 },
        { order_by => { -desc => 'published_date' } },
    );
    $c->render(
        'blog_list',
        items => \@blog_entries,
    );
};

# View a single blog entry
get '/blog/:blog_entry_id' => sub( $c ) {
    my $blog_entry = $c->yancy->get(
        blog_entries => $c->param( 'blog_entry_id' ),
    );
    $c->render(
        'blog_entry',
        item => $blog_entry,
    );
};

Forms

The Yancy::Plugin::Form plugin can generate input fields or entire forms based on your schema information. The annotations in your schema appear in the forms to help users fill them out. Additionally, with the Yancy::Plugin::Form::Bootstrap4 module, Yancy can create forms using Twitter Bootstrap components.

# Load the form plugin
app->yancy->plugin( 'Form::Bootstrap4' );

# Edit a blog entry
any [ 'GET', 'POST' ], '/edit/:blog_entry_id' => sub( $c ) {
    if ( $c->req->method eq 'GET' ) {
        my $blog_entry = $c->yancy->get(
            blog_entries => $c->param( 'blog_entry_id' ),
        );
        return $c->render(
            'blog_entry',
            item => $blog_entry,
        );
    }
    my $id = $c->param( 'blog_entry_id' );
    my $item = $c->req->params->to_hash;
    delete $item->{csrf_token}; # See https://docs.mojolicious.org/Mojolicious/Guides/Rendering#Cross-site-request-forgery
    $c->yancy->set( blog_entries => $id, $c->req->params->to_hash );
    $c->redirect_to( '/blog/' . $id );
};

__DATA__
@@ blog_form.html.ep
%= $c->yancy->form->form_for( 'blog_entries', item => stash 'item' )

Controllers

Yancy can add basic CRUD operations without writing the code yourself. The Yancy::Controller::Yancy module uses the schema information to show, search, edit, create, and delete database items.

# A rewrite of the routes above to use Yancy::Controller::Yancy

# View a list of blog entries
get '/' => {
    controller => 'yancy',
    action => 'list',
    schema => 'blog_entries',
    filter => { published => 1 },
    order_by => { -desc => 'published_date' },
} => 'blog.list';

# View a single blog entry
get '/blog/:blog_entry_id' => {
    controller => 'yancy',
    action => 'get',
    schema => 'blog_entries',
} => 'blog.get';

# Load the form plugin
app->yancy->plugin( 'Form::Bootstrap4' );

# Edit a blog entry
any [ 'GET', 'POST' ], '/edit/:blog_entry_id' => {
    controller => 'yancy',
    action => 'set',
    schema => 'blog_entries',
    template => 'blog_form',
    redirect_to => 'blog.get',
} => 'blog.edit';

__DATA__
@@ blog_form.html.ep
%= $c->yancy->form->form_for( 'blog_entries' )

Plugins

Yancy also has plugins for...

More development will be happening here soon!

AUTHOR

Doug Bell <preaction@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by Doug Bell.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.